# aws_recommendations

aws_recommendations package gives recommendation for you aws account

Release Notes:
# v0.0.3
1. Minor bug fixes

# v0.0.2
1. Improved code quality
2. Multi region now supported

# v0.0.1 - Initial Release
